This introduces LipoProteinLipase (lpl), a simple tool for creating fat binaries. It represents a direct replacement of the creaky hccgenco.sh script, which had various issues. The format it uses is that of a code object bundle, generated by the Clang Offload Bundler. The output is always suffixed with the ".adipose" extension. It is shared with HCC. The hipcc script and associated tests are modified to use lpl. Help can be obtained by invoking lpl --help. A more computer-sciency / corporate friendly name is likely to be beneficial, which is a reason for choosing easily searchable/replaceable names such as lpl or adipose.

[ROCm/hip-tests commit: 182156b12b]
Cette révision appartient à :
Alex Voicu
2017-12-08 04:22:57 +00:00
Parent ce4628065a
révision dd60eaa156
5 fichiers modifiés avec 8 ajouts et 11 suppressions
+1 -2
Voir le fichier
@@ -35,7 +35,7 @@ THE SOFTWARE.
#define LEN 64
#define SIZE LEN<<2
#define fileName "vcpy_kernel.code"
#define fileName "vcpy_kernel.code.adipose"
#define kernel_name "hello_world"
#define HIP_CHECK(status) \
@@ -72,7 +72,6 @@ int main(){
uint32_t one = 1;
struct {
uint32_t _hidden[6];
void * _Ad;
void * _Bd;
} args;
+1 -2
Voir le fichier
@@ -30,7 +30,7 @@ THE SOFTWARE.
#define LEN 64
#define SIZE LEN<<2
#define fileName "vcpy_kernel.code"
#define fileName "vcpy_kernel.code.adipose"
#define kernel_name "hello_world"
#define HIP_CHECK(status) \
@@ -68,7 +68,6 @@ int main(){
uint32_t one = 1;
struct {
uint32_t _hidden[6];
void * _Ad;
void * _Bd;
} args;
+1 -1
Voir le fichier
@@ -22,7 +22,7 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
extern "C" __global__ void hello_world(hipLaunchParm lp, float *a, float *b)
extern "C" __global__ void hello_world(float *a, float *b)
{
int tx = hipThreadIdx_x;
b[tx] = a[tx];